@@ -11,7 +11,7 @@ use Carp;
 use Amibroker::OLE::Interface;
 use Amibroker::OLE::APXCreator;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my $AMIBROKER_SERVICE_RUNS = 1000;
 
@@ -73,7 +73,7 @@ sub new {
     print
 '[WARN] : No \'profit_from\' supplied to Amibroker          : Default 0 is taken '
       . "\n"
-      unless $self->{_profit_from};
+      unless $self->{profit_from};
     print
 '[WARN] : No \'profit_to\' supplied to Amibroker            : Default 20000 is taken '
       . "\n"
@@ -238,7 +238,7 @@ sub run_optimize_engine {
     #
     # Step 10 : Slurp AFL Template file to a string
     #
-    my $slurpAfl = File::Slurp::read_file($copiedFile);
+   # my $slurpAfl = File::Slurp::read_file($copiedFile);
     #
     # Step 11 : Get the Sandbox and Result file path
     #
@@ -258,13 +258,29 @@ sub run_optimize_engine {
     # Step 12 : Create APX file
     #
     my $range = 0;    # by default range_type is all quotes
-    $range = 3
-      if ( $self->{from} && $self->{to} )
-      ;               # if from & to dates are supplied, then go for From_and_To
+	
+	# if from & to dates are supplied, then go for From_and_To
+    if ( $self->{from} && $self->{to} ) {
+		$range = 3;
+	}
+	else {
+		$self->{from} = '01-01-2000';
+		$self->{to}   = '31-12-2015';
+	}
+	print "====================================================\n";
+	print "sandbox_xml = $sandbox_xml\n";
+	print "copiedFile = $copiedFile\n";
+	print "timeframe = $self->{timeframe}\n";	
+	print "from = $self->{from}\n";	
+	print "to = $self->{to}\n";	
+	print "range_type = $range\n";	
+	print "apply_to = 1\n";	
+	
+	print "====================================================\n";
     my $apxFile = Amibroker::OLE::APXCreator::create_apx_file(
         {
             apx_file   => $sandbox_xml,
-            afl_file   => $slurpAfl,
+            afl_file   => $copiedFile,
             symbol     => $script,
             timeframe  => $self->{timeframe},
             from       => $self->{from},
@@ -276,6 +292,10 @@ sub run_optimize_engine {
     #
     # Step 13 : Run Amibroker Optimizer
     #
+	print "apx_file = $apxFile\n";
+	print "result_file = $resultFile\n";
+	print "symbol = $self->{symbol}\n";
+	
     my $runStatus = $broker->run_analysis(
         {
             action      => 5,
@@ -659,7 +679,7 @@ sub DESTROY {
     my $broker = $self->{_broker};
     $broker->shutdown_amibroker_engine() if ( $self->{_broker} );
     $self->copy_sandbox();
-    $self->clear_sandbox();
+ #   $self->clear_sandbox();
     return 1;
 }
 
@@ -674,7 +694,7 @@ Amibroker::AFL::Optimizer - Auto Optimizer framework for ALL Stocks across ALL t
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
